==> gdalautotest-3.9.3.tar.gz: gdalautotest-3.9.3/gdrivers/pnm.py <==
#!/usr/bin/env pytest
###############################################################################
# $Id$
#
# Project:  GDAL/OGR Test Suite
# Purpose:  PNM (Portable Anyware Map) Testing.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
#
###############################################################################
# Copyright (c) 2007, Frank Warmerdam <warmerdam@pobox.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.
###############################################################################

import gdaltest
import pytest

from osgeo import gdal

pytestmark = pytest.mark.require_driver("PNM")

###############################################################################
# Read Test grayscale (PGM)


def test_pnm_1():

    tst = gdaltest.GDALTest("PNM", "pnm/byte.pgm", 1, 4672)

    tst.testOpen()


###############################################################################
# Write Test grayscale (PGM)


def test_pnm_2():

    tst = gdaltest.GDALTest("PNM", "pnm/byte.pgm", 1, 4672)

    tst.testCreateCopy(vsimem=1)


###############################################################################
# Read Test RGB (PPM)


def test_pnm_3():

    tst = gdaltest.GDALTest("PNM", "pnm/rgbsmall.ppm", 2, 21053)

    tst.testOpen()


###############################################################################
# Write Test RGB (PPM)


def test_pnm_4():

    tst = gdaltest.GDALTest("PNM", "pnm/rgbsmall.ppm", 2, 21053)

    tst.testCreateCopy()


@pytest.mark.parametrize("nbands", [1, 3])
@gdaltest.disable_exceptions()
def test_pnm_write_non_standard_extension(nbands):
    gdal.ErrorReset()
    with gdal.quiet_errors():
        gdal.GetDriverByName("PNM").Create("foo.foo", 1, 1, nbands)
    assert gdal.GetLastErrorType() != 0
    gdal.Unlink("foo.foo")

==> gdalautotest-3.11.4.tar.gz: gdalautotest-3.11.4/gdrivers/pnm.py <==
#!/usr/bin/env pytest
###############################################################################
#
# Project:  GDAL/OGR Test Suite
# Purpose:  PNM (Portable Anyware Map) Testing.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
#
###############################################################################
# Copyright (c) 2007, Frank Warmerdam <warmerdam@pobox.com>
#
# SPDX-License-Identifier: MIT
###############################################################################

import gdaltest
import pytest

from osgeo import gdal

pytestmark = pytest.mark.require_driver("PNM")

###############################################################################
# Read Test grayscale (PGM)


def test_pnm_1():

    tst = gdaltest.GDALTest("PNM", "pnm/byte.pgm", 1, 4672)

    tst.testOpen()


###############################################################################
# Write Test grayscale (PGM)


def test_pnm_2():

    tst = gdaltest.GDALTest("PNM", "pnm/byte.pgm", 1, 4672)

    tst.testCreateCopy(vsimem=1)


###############################################################################
# Read Test RGB (PPM)


def test_pnm_3():

    tst = gdaltest.GDALTest("PNM", "pnm/rgbsmall.ppm", 2, 21053)

    tst.testOpen()


###############################################################################
# Write Test RGB (PPM)


def test_pnm_4():

    tst = gdaltest.GDALTest("PNM", "pnm/rgbsmall.ppm", 2, 21053)

    tst.testCreateCopy()


@pytest.mark.parametrize("nbands", [1, 3])
@gdaltest.disable_exceptions()
def test_pnm_write_non_standard_extension(nbands):
    gdal.ErrorReset()
    with gdal.quiet_errors():
        gdal.GetDriverByName("PNM").Create("foo.foo", 1, 1, nbands)
    assert gdal.GetLastErrorType() != 0
    gdal.Unlink("foo.foo")


@gdaltest.disable_exceptions()
def test_pnm_read_int_max():

    with gdal.quiet_errors():
        ds = gdal.Open("data/pnm/int_max.pgm")
    if ds is None:
        pytest.skip("not enough memory")
    ds.GetRasterBand(1).Checksum()
